/*
|| This file is part of Pike. For copyright information see COPYRIGHT.
|| Pike is distributed under GPL, LGPL and MPL. See the file COPYING
|| for more information.
|| $Id: acconfig.h,v 1.7 2005/03/21 15:29:26 grubba Exp $
*/

/*
 * Config-file for the Pike sybase driver module
 *
 * by Francesco Chemolli
 */

#ifndef __PIKE_SYBASE_CONFIG_H
#define __PIKE_SYBASE_CONFIG_H

@TOP@

/* Define to enable the sybase module. */
#undef HAVE_SYBASE 

@BOTTOM@

#endif /* __PIKE_SYBASE_CONFIG_H */
